@@ -60,6 +60,9 @@ class totemPlugin {
 
     nsresult DoCommand (const char *aCommand);
     nsresult SetVolume (gdouble aVolume);
+    nsresult ClearPlaylist (void);
+    nsresult AddItem (const nsACString &aURI);
+    nsresult SetFullscreen (gboolean enabled);
 
     nsresult SetSrc (const nsACString &aURL);
 
@@ -123,6 +126,10 @@ class totemPlugin {
     					  guint aDuration,
     					  char *aState,
 					  void *aData);
+    static void PR_CALLBACK PropertyChangeCallback (DBusGProxy  *proxy,
+    						    const char *type,
+						    GValue *value,
+						    void *aData);
 
     static void PR_CALLBACK ViewerSetWindowCallback (DBusGProxy *aProxy,
 						     DBusGProxyCall *aCall,
@@ -211,6 +218,8 @@ class totemPlugin {
     PRUint32 mTime;
     PRUint32 mDuration;
     TotemStates mState;
+    double mVolume;
+    PRBool mIsFullscreen;
 
 #ifdef TOTEM_GMP_PLUGIN
   public:
@@ -297,6 +306,6 @@ typedef struct {
   const char *mime_alias;
 } totemPluginMimeEntry;
 
-char *totem_plugin_get_long_description (void);
+const char *totem_plugin_get_long_description (void);
 
 #endif /* __TOTEM_PLUGIN_H__ */
